data{
	int<lower=0> N1;
	int<lower=0> S1[N1];
	int<lower=0> x1[N1];
	int<lower=0> N2;
	int<lower=0> S2[N2];
	int<lower=0> x2[N2];
	int<lower=0> N3;
	int<lower=0> S3[N3];
	int<lower=0> x3[N3];
}
transformed data{
	real S1_m;
	real S2_m;
	real S3_m;
	S1_m = sum(S1)/N1;
	S2_m = sum(S2)/N2;
	S3_m = sum(S3)/N3;
}
parameters{
	real<lower=0,upper=1> mu1;
	real<lower=0.01> kap1;
	real<lower=0,upper=1> mu2;
	real<lower=0.01> kap2;
	real<lower=0,upper=1> mu3;
	real<lower=0.01> kap3;
}
transformed parameters{
	real<lower=0> a1;
	real<lower=0> b1;
	real<lower=0> a2;
	real<lower=0> b2;
	real<lower=0> a3;
	real<lower=0> b3;
	a1 = mu1 * kap1;
	b1 = kap1 - a1;
	a2 = mu2 * kap2;
	b2 = kap2 - a2;
	a3 = mu3 * kap3;
	b3 = kap3 - a3;
}
model{
	kap1 ~ pareto(0.1,1.5);
	kap2 ~ pareto(0.1,1.5);
	kap3 ~ pareto(0.1,1.5);
	for(i in 1:N1){
		x1[i] ~ beta_binomial(S1[i],a1,b1);
	}
	for(i in 1:N2){
		x2[i] ~ beta_binomial(S2[i],a2,b2);
	}
	for(i in 1:N3){
		x3[i] ~ beta_binomial(S3[i],a3,b3);
	}
}
generated quantities{
	real eta1;
	real eta2;
	real U1;
	real U2;
	real U3;
	real gamma;
	real omega1;
	real omega2;
	eta1 = mu1-mu2;
	eta2 = mu2-mu3;
	U1= int_step(eta1);
	U2= int_step(eta2);
	U3= U1*U2;
	gamma=(mu1*(1-mu3))/(mu3*(1-mu1));
	omega1 = S1_m*(a1*b1*(a1+b1+S1_m))/((a1+b1)^2*(a1+b1+1));
	omega2 = S1_m*(a1)/(a1+b1);	
}