data{
	int<lower=0> N; // number of subjects
	int<lower=0> H; // number of objects
	int<lower=0> J; // number of items
	int<lower=0> J2; // 2*number of items
	int<lower=0> KK; // number of combination of selects
	int<lower=1,upper=KK> res[N,J]; // response data 
	int<lower=1,upper=H> makeComb[J2,KK]; //
}

parameters{
	real theta[N];
	vector[H] beta;
	real<lower=0> tau_b;
}

transformed parameters{
	real sigma2_b;
	vector[KK] p[N,J];
	vector[KK] beta_plus_Mat[J];
	vector[KK] beta_minus_Mat[J];

	sigma2_b = 1/tau_b;

	for(j in 1:J){
		for(kk in 1:KK){
			beta_plus_Mat[j,kk] = (beta[makeComb[(2*j-1),kk]] + beta[makeComb[(2*j),kk]])/2;
			beta_minus_Mat[j,kk] = 2*(beta[makeComb[(2*j-1),kk]] - beta[makeComb[(2*j),kk]]);
		}
	}

	for(i in 1:N){
		for(j in 1:J){
			p[i,j] = softmax(beta_minus_Mat[j] .* (theta[i] - beta_plus_Mat[j]));
		}
	}
}
model{
	theta ~ normal(0.0,1.0);
	beta ~ normal(0.0,sqrt(sigma2_b));
	tau_b ~ gamma(1.0E-3,1.0E-3);
	for(i in 1:N){
		for(j in 1:J){
			res[i,j] ~ categorical(p[i,j]);
		}
	}
}

