data{
	int<lower=1> T;
	int<lower=1> K;
	int<lower=1,upper=K> y[T];
	int<lower=0,upper=100> W[T];
	int<lower=-1250,upper=0> L[T];
}
parameters{
	real<lower=0,upper=1> w;
	real<lower=0,upper=1> a;
	real<lower=-5,upper=5> c;
}
transformed parameters{
	real<lower=0> theta[T];
	real v[T];
	vector[K] Ev[T];
	simplex[K] p[T];

	for(t in 1:T){
		theta[t]=pow((0.1*t),c);
		v[t]=(1-w)*W[t]+w*L[t];
	}
	for(k in 1:K){
		Ev[1,k]=0;
		p[1,k]=0.25;
	}

	for(t in 2:T){
	  for(k in 1:K){
	    if(y[t-1]==k)
		Ev[t,k]=Ev[t-1,k]+a*(v[t-1]-Ev[t-1,k]);
	    else
		Ev[t,k]=Ev[t-1,k];
	  }
	}
	for(t in 2:T){
		p[t]=softmax(theta[t]*Ev[t]);
	}
}
model{
	for(t in 1:T){
		y[t]~categorical(p[t]);
	}
}



