data{
	int<lower=1> T;
	int<lower=1> K;
	int<lower=1> N;
	matrix[3,3] R;
	int<lower=1,upper=K> y[T,N];
	int<lower=0,upper=100> W[T,N];
	int<lower=-1250,upper=0> L[T,N];
}
parameters{
	vector[3] Eta[N];
	vector[3] Mu;
	cov_matrix[3] Sigma;
}
transformed parameters{
	real<lower=0> theta[T,N];
	real v[T,N];
	vector[K] Ev[T,N];
	simplex[K] p[T,N];
	real<lower=0,upper=1> w[N];
	real<lower=0,upper=1> a[N];
	real c[N];

	for(n in 1:N){
		w[n]=normal_cdf(Eta[n,1],Mu[1],sqrt(Sigma[1,1]));
		a[n]=normal_cdf(Eta[n,2],Mu[2],sqrt(Sigma[2,2]));
		c[n]=Eta[n,3];
	}
	for(t in 1:T){
	   for(n in 1:N){
		theta[t,n]=pow((0.1*t),c[n]);
		v[t,n]=(1-w[n])*W[t,n]+w[n]*L[t,n];
	   }
	}
	for(n in 1:N){
	   for(k in 1:K){
		Ev[1,n,k]=0;
		p[1,n,k]=0.25;
	   }
	}
	for(t in 2:T){
	   for(n in 1:N){
	     for(k in 1:K){
		if(y[t-1,n]==k)
		   Ev[t,n,k]=Ev[t-1,n,k]+a[n]*( v[t-1,n]-Ev[t-1,n,k] );
		else
		   Ev[t,n,k]=Ev[t-1,n,k];
		}
	   }
	}
	for(t in 2:T){
	   for(n in 1:N){
     	      p[t,n]=softmax(theta[t,n]*Ev[t,n]);
	   }
	}
}
model{
	for(i in 1:3){
		Mu[i]~normal(0,1);
	}
	Sigma~inv_wishart(3,R);

	Eta~multi_normal(Mu,Sigma);

	for(n in 1:N){
   	   for(t in 1:T){
		y[t,n]~categorical(p[t,n]);
	   }
	}
}
generated quantities{
	matrix[3,3] rho;

	for(i in 1:3){
	  for(j in 1:3){
		rho[i,j]=Sigma[i,j]/sqrt(Sigma[i,i]*Sigma[j,j]);
	  }
	}
}



